<?php

return [
    'number.decimals_separator' => '.',
    'number.thousands_separator' => ',',
    'None' => 'Tiada',
    'Edit' => 'Sunting',
    'Remove' => 'Hapus',
    'Yes' => 'Ya',
    'No' => 'Tidak',
    'cancel' => 'batal',
    'or' => 'atau',
    'Yellow' => 'Kuning',
    'Blue' => 'Biru',
    'Green' => 'Hijau',
    'Purple' => 'Ungu',
    'Red' => 'Merah',
    'Orange' => 'Oren',
    'Grey' => 'Kelabu',
    'Brown' => 'Coklat',
    'Deep Orange' => 'Oren Gelap',
    'Dark Grey' => 'Kelabu Malap',
    'Pink' => 'Merah Jambu',
    'Teal' => 'Teal',
    'Cyan' => 'Sian',
    'Lime' => 'Lime',
    'Light Green' => 'Hijau Muda',
    'Amber' => 'Amber',
    'Save' => 'Simpan',
    'Login' => 'Masuk',
    'Official website:' => 'Laman rasmi :',
    'Unassigned' => 'Belum ditugaskan',
    'View this task' => 'Lihat tugas ini',
    'Remove user' => 'Hapus pengguna',
    'Do you really want to remove this user: "%s"?' => 'Anda yakin mahu menghapus pengguna ini : « %s » ?',
    'All users' => 'Semua pengguna',
    'Username' => 'Nama pengguna',
    'Password' => 'Kata laluan',
    'Administrator' => 'Pentadbir',
    'Sign in' => 'Masuk',
    'Users' => 'Para Pengguna',
    'Forbidden' => 'Larangan',
    'Access Forbidden' => 'Akses Dilarang',
    'Edit user' => 'Ubah Pengguna',
    'Logout' => 'Keluar',
    'Bad username or password' => 'Nama pengguna atau kata laluan tidak sepadan',
    'Edit project' => 'Ubah projek',
    'Name' => 'Nama',
    'Projects' => 'Projek',
    'No project' => 'Tiada projek',
    'Project' => 'Projek',
    'Status' => 'Status',
    'Tasks' => 'Tugasan',
    'Board' => 'Papan',
    'Actions' => 'Tindakan',
    'Inactive' => 'Tidak Aktif',
    'Active' => 'Aktif',
    'Unable to update this board.' => 'Tidak berupaya mengemaskini papan ini',
    'Disable' => 'Nyah-Upaya',
    'Enable' => 'Aktifkan',
    'New project' => 'Projek Baru',
    'Do you really want to remove this project: "%s"?' => 'Anda yakin mahu menghapus projek ini : « %s » ?',
    'Remove project' => 'Hapus projek',
    'Edit the board for "%s"' => 'Ubah papan untuk « %s »',
    'Add a new column' => 'Tambah kolom baru',
    'Title' => 'Judul',
    'Assigned to %s' => 'Ditugaskan ke %s',
    'Remove a column' => 'Hapus kolom',
    'Unable to remove this column.' => 'Tidak dapat menghapus kolom ini.',
    'Do you really want to remove this column: "%s"?' => 'Apakah anda yakin akan menghapus kolom ini : « %s » ?',
    'Settings' => 'Penetapan',
    'Application settings' => 'Penetapan aplikasi',
    'Language' => 'Bahasa',
    'Webhook token:' => 'Token webhook :',
    'API token:' => 'Token API :',
    'Database size:' => 'Saiz pengkalan data:',
    'Download the database' => 'Muat turun pengkalan data',
    'Optimize the database' => 'Optimakan pengkalan data',
    '(VACUUM command)' => '(perintah VACUUM)',
    '(Gzip compressed Sqlite file)' => '(File Sqlite yang termampat Gzip)',
    'Close a task' => 'Tutup tugas',
    'Column' => 'Kolom',
    'Color' => 'Warna',
    'Assignee' => 'Orang yang ditugaskan',
    'Create another task' => 'Buat tugas lain',
    'New task' => 'Tugasan baru',
    'Open a task' => 'Buka tugas',
    'Do you really want to open this task: "%s"?' => 'Anda yakin untuk buka tugas ini : « %s » ?',
    'Back to the board' => 'Kembali ke papan',
    'There is nobody assigned' => 'Tidak ada orang yand ditugaskan',
    'Column on the board:' => 'Kolom di dalam papan : ',
    'Close this task' => 'Tutup tugas ini',
    'Open this task' => 'Buka tugas ini',
    'There is no description.' => 'Tidak ada keterangan.',
    'Add a new task' => 'Tambah tugas baru',
    'The username is required' => 'Nama pengguna adalah wajib',
    'The maximum length is %d characters' => 'Panjang maksimum adalah %d karakter',
    'The minimum length is %d characters' => 'Panjang minimum adalah %d karakter',
    'The password is required' => 'Kata laluan adalah wajib',
    'This value must be an integer' => 'Nilai ini harus integer',
    'The username must be unique' => 'Nama pengguna semestinya unik',
    'The user id is required' => 'Id Pengguna adalah wajib',
    'Passwords don\'t match' => 'Kata laluan tidak sepadan',
    'The confirmation is required' => 'Pengesahan diperlukan',
    'The project is required' => 'Projek diperlukan',
    'The id is required' => 'Id diperlukan',
    'The project id is required' => 'Id projek diperlukan',
    'The project name is required' => 'Nama projek diperlukan',
    'The title is required' => 'Judul diperlukan',
    'Settings saved successfully.' => 'Penetapan berjaya disimpan.',
    'Unable to save your settings.' => 'Tidak dapat menyimpan penetapan anda.',
    'Database optimization done.' => 'Optimasi pengkalan data selesai.',
    'Your project has been created successfully.' => 'Projek anda berhasil dibuat.',
    'Unable to create your project.' => 'Tidak dapat membuat projek anda.',
    'Project updated successfully.' => 'projek berhasil diperbaharui.',
    'Unable to update this project.' => 'Tidak dapat memperbaharui projek ini.',
    'Unable to remove this project.' => 'Tidak dapat menghapus projek ini.',
    'Project removed successfully.' => 'projek berhasil dihapus.',
    'Project activated successfully.' => 'projek berhasil diaktivasi.',
    'Unable to activate this project.' => 'Tidak dapat mengaktifkan projek ini.',
    'Project disabled successfully.' => 'projek berhasil dinonaktifkan.',
    'Unable to disable this project.' => 'Tidak dapat menonaktifkan projek ini.',
    'Unable to open this task.' => 'Tidak dapat membuka tugas ini.',
    'Task opened successfully.' => 'Tugas berhasil dibuka.',
    'Unable to close this task.' => 'Tidak dapat menutup tugas ini.',
    'Task closed successfully.' => 'Tugas berhasil ditutup.',
    'Unable to update your task.' => 'Tidak dapat memperbaharui tugas ini.',
    'Task updated successfully.' => 'Tugas berhasil diperbaharui.',
    'Unable to create your task.' => 'Tidak dapat membuat tugas anda.',
    'Task created successfully.' => 'Tugas berhasil dibuat.',
    'User created successfully.' => 'Pengguna berhasil dibuat.',
    'Unable to create your user.' => 'Tidak dapat membuat pengguna anda.',
    'User updated successfully.' => 'Pengguna berhasil diperbaharui.',
    'User removed successfully.' => 'pengguna berhasil dihapus.',
    'Unable to remove this user.' => 'Tidak dapat menghapus pengguna ini.',
    'Board updated successfully.' => 'Papan berhasil diperbaharui.',
    'Ready' => 'Siap',
    'Backlog' => 'Tertunda',
    'Work in progress' => 'Sedang dalam pengerjaan',
    'Done' => 'Selesai',
    'Application version:' => 'Versi aplikasi :',
    'Id' => 'Id.',
    'Public link' => 'Pautan publik',
    'Timezone' => 'Zona waktu',
    'Sorry, I didn\'t find this information in my database!' => 'Maaf, saya tidak menemukan informasi ini dalam basis data saya !',
    'Page not found' => 'Halaman tidak ditemukan',
    'Complexity' => 'Kompleksitas',
    'Task limit' => 'Batas tugas.',
    'Task count' => 'Jumlah tugas',
    'User' => 'Pengguna',
    'Comments' => 'Komentar',
    'Comment is required' => 'Komentar diperlukan',
    'Comment added successfully.' => 'Komentar berhasil ditambahkan.',
    'Unable to create your comment.' => 'Tidak dapat menambahkan komentar anda.',
    'Due Date' => 'Batas Tanggal Terakhir',
    'Invalid date' => 'Tanggal tidak valid',
    'Automatic actions' => 'Tindakan otomatis',
    'Your automatic action has been created successfully.' => 'Tindakan otomatis anda berhasil dibuat.',
    'Unable to create your automatic action.' => 'Tidak dapat membuat tindakan otomatis anda.',
    'Remove an action' => 'Hapus tindakan',
    'Unable to remove this action.' => 'Tidak dapat menghapus tindakan ini',
    'Action removed successfully.' => 'Tindakan berhasil dihapus.',
    'Automatic actions for the project "%s"' => 'Tindakan otomatis untuk projek ini « %s »',
    'Add an action' => 'Tambah tindakan',
    'Event name' => 'Nama acara',
    'Action' => 'Tindakan',
    'Event' => 'Acara',
    'When the selected event occurs execute the corresponding action.' => 'Ketika acara yang dipilih terjadi, melakukan tindakan yang sesuai.',
    'Next step' => 'Langkah selanjutnya',
    'Define action parameters' => 'Definisi parameter tindakan',
    'Do you really want to remove this action: "%s"?' => 'Apakah anda yakin akan menghapus tindakan ini « %s » ?',
    'Remove an automatic action' => 'Hapus tindakan otomatis',
    'Assign the task to a specific user' => 'Menetapkan tugas untuk pengguna tertentu',
    'Assign the task to the person who does the action' => 'Memberikan tugas untuk orang yang melakukan tindakan',
    'Duplicate the task to another project' => 'Duplikasi tugas ke projek lain',
    'Move a task to another column' => 'Pindahkan tugas ke kolom lain',
    'Task modification' => 'Modifikasi tugas',
    'Task creation' => 'Membuat tugas',
    'Closing a task' => 'Menutup tugas',
    'Assign a color to a specific user' => 'Menetapkan warna untuk pengguna tertentu',
    'Position' => 'Posisi',
    'Duplicate to project' => 'Duplikasi ke projek lain',
    'Duplicate' => 'Duplikasi',
    'Link' => 'Pautan',
    'Comment updated successfully.' => 'Komentar berhasil diperbaharui.',
    'Unable to update your comment.' => 'Tidak dapat memperbaharui komentar anda.',
    'Remove a comment' => 'Hapus komentar',
    'Comment removed successfully.' => 'Komentar berhasil dihapus.',
    'Unable to remove this comment.' => 'Tidak dapat menghapus komentar ini.',
    'Do you really want to remove this comment?' => 'Apakah anda yakin akan menghapus komentar ini ?',
    'Current password for the user "%s"' => 'Kata laluan saat ini untuk pengguna « %s »',
    'The current password is required' => 'Kata laluan saat ini diperlukan',
    'Wrong password' => 'Kata laluan salah',
    'Unknown' => 'Tidak diketahui',
    'Last logins' => 'Masuk terakhir',
    'Login date' => 'Tanggal masuk',
    'Authentication method' => 'Metode otentifikasi',
    'IP address' => 'Alamat IP',
    'User agent' => 'Agen Pengguna',
    'Persistent connections' => 'Koneksi persisten',
    'No session.' => 'Tidak ada sesi.',
    'Expiration date' => 'Tanggal kadaluarsa',
    'Remember Me' => 'Ingat Saya',
    'Creation date' => 'Tanggal dibuat',
    'Everybody' => 'Semua orang',
    'Open' => 'Terbuka',
    'Closed' => 'Ditutup',
    'Search' => 'Cari',
    'Nothing found.' => 'Tidak ditemukan.',
    'Due date' => 'Batas tanggal terakhir',
    'Description' => 'Deskripsi',
    '%d comments' => '%d komentar',
    '%d comment' => '%d komentar',
    'Email address invalid' => 'Alamat email tidak valid',
    'Your external account is not linked anymore to your profile.' => 'Akaun eksternal anda tidak lagi terhubung ke profil anda.',
    'Unable to unlink your external account.' => 'Tidak dapat memutuskan Akaun eksternal anda.',
    'External authentication failed' => 'Otentifikasi eksternal gagal',
    'Your external account is linked to your profile successfully.' => 'Akaun eksternal anda berhasil dihubungkan ke profil anda.',
    'Email' => 'Email',
    'Task removed successfully.' => 'Tugas berhasil dihapus.',
    'Unable to remove this task.' => 'Tidak dapat menghapus tugas ini.',
    'Remove a task' => 'Hapus tugas',
    'Do you really want to remove this task: "%s"?' => 'Apakah anda yakin akan menghapus tugas ini « %s » ?',
    'Assign automatically a color based on a category' => 'Otomatis menetapkan warna berdasarkan kategori',
    'Assign automatically a category based on a color' => 'Otomatis menetapkan kategori berdasarkan warna',
    'Task creation or modification' => 'Tugas dibuat atau di mofifikasi',
    'Category' => 'Kategori',
    'Category:' => 'Kategori :',
    'Categories' => 'Kategori',
    'Your category has been created successfully.' => 'Kategori anda berhasil dibuat.',
    'This category has been updated successfully.' => 'Kategori anda berhasil diperbaharui.',
    'Unable to update this category.' => 'Tidak dapat memperbaharui kategori anda.',
    'Remove a category' => 'Hapus kategori',
    'Category removed successfully.' => 'Kategori berhasil dihapus.',
    'Unable to remove this category.' => 'Tidak dapat menghapus kategori ini.',
    'Category modification for the project "%s"' => 'Modifikasi kategori untuk projek « %s »',
    'Category Name' => 'Nama Kategori',
    'Add a new category' => 'Tambah kategori baru',
    'Do you really want to remove this category: "%s"?' => 'Apakah anda yakin akan menghapus kategori ini « %s » ?',
    'All categories' => 'Semua kategori',
    'No category' => 'Tidak ada kategori',
    'The name is required' => 'Nama diperlukan',
    'Remove a file' => 'Hapus berkas',
    'Unable to remove this file.' => 'Tidak dapat menghapus berkas ini.',
    'File removed successfully.' => 'Berkas berhasil dihapus.',
    'Attach a document' => 'Lampirkan dokumen',
    'Do you really want to remove this file: "%s"?' => 'Apakah anda yakin akan menghapus berkas ini « %s » ?',
    'Attachments' => 'Lampiran',
    'Edit the task' => 'Modifikasi tugas',
    'Add a comment' => 'Tambahkan komentar',
    'Edit a comment' => 'Modifikasi komentar',
    'Summary' => 'Ringkasan',
    'Time tracking' => 'Pelacakan waktu',
    'Estimate:' => 'Estimasi :',
    'Spent:' => 'Menghabiskan:',
    'Do you really want to remove this sub-task?' => 'Apakah anda yakin akan menghapus sub-tugas ini ?',
    'Remaining:' => 'Tersisa:',
    'hours' => 'jam',
    'estimated' => 'perkiraan',
    'Sub-Tasks' => 'Sub-tugas',
    'Add a sub-task' => 'Tambahkan sub-tugas',
    'Original estimate' => 'Perkiraan semula',
    'Create another sub-task' => 'Tambahkan sub-tugas lainnya',
    'Time spent' => 'Waktu yang dihabiskan',
    'Edit a sub-task' => 'Modifikasi sub-tugas',
    'Remove a sub-task' => 'Hapus sub-tugas',
    'The time must be a numeric value' => 'Waktu harus berisikan numerik',
    'Todo' => 'Yang harus dilakukan',
    'In progress' => 'Sedang proses',
    'Sub-task removed successfully.' => 'Sub-tugas berhasil dihapus.',
    'Unable to remove this sub-task.' => 'Tidak dapat menghapus sub-tugas.',
    'Sub-task updated successfully.' => 'Sub-tugas berhasil diperbaharui.',
    'Unable to update your sub-task.' => 'Tidak dapat memperbaharui sub-tugas anda.',
    'Unable to create your sub-task.' => 'Tidak dapat membuat sub-tugas anda.',
    'Maximum size: ' => 'Ukuran maksimum: ',
    'Display another project' => 'Lihat projek lain',
    'Created by %s' => 'Dibuat oleh %s',
    'Tasks Export' => 'Ekspor Tugas',
    'Start Date' => 'Tanggal Mulai',
    'Execute' => 'Eksekusi',
    'Task Id' => 'Id Tugas',
    'Creator' => 'Pembuat',
    'Modification date' => 'Tanggal modifikasi',
    'Completion date' => 'Tanggal penyelesaian',
    'Clone' => 'Klon',
    'Project cloned successfully.' => 'Kloning projek berhasil.',
    'Unable to clone this project.' => 'Tidak dapat mengkloning projek.',
    'Enable email notifications' => 'Aktifkan pemberitahuan dari email',
    'Task position:' => 'Posisi tugas :',
    'The task #%d has been opened.' => 'Tugas #%d telah dibuka.',
    'The task #%d has been closed.' => 'Tugas #%d telah ditutup.',
    'Sub-task updated' => 'Sub-tugas diperbaharui',
    'Title:' => 'Judul :',
    'Status:' => 'Status :',
    'Assignee:' => 'Ditugaskan ke :',
    'Time tracking:' => 'Pelacakan waktu :',
    'New sub-task' => 'Sub-tugas baru',
    'New attachment added "%s"' => 'Lampiran baru ditambahkan « %s »',
    'New comment posted by %s' => 'Komentar baru ditambahkan oleh « %s »',
    'New comment' => 'Komentar baru',
    'Comment updated' => 'Komentar diperbaharui',
    'New subtask' => 'Sub-tugas baru',
    'I only want to receive notifications for these projects:' => 'Saya ingin menerima pemberitahuan hanya untuk projek-projek yang dipilih :',
    'view the task on Kanboard' => 'lihat tugas di Kanboard',
    'Public access' => 'Akses awam',
    'Disable public access' => 'Nyahaktifkan akses awam',
    'Enable public access' => 'Aktifkan akses awam',
    'Public access disabled' => 'Akses awam dinyahaktif',
    'Move the task to another project' => 'Pindahkan tugas ke projek lain',
    'Move to project' => 'Pindahkan ke projek lain',
    'Do you really want to duplicate this task?' => 'Anda yakin mengembarkan tugas ini ?',
    'Duplicate a task' => 'Kembarkan tugas',
    'External accounts' => 'Akaun luaran',
    'Account type' => 'Jenis Akaun',
    'Local' => 'Lokal',
    'Remote' => 'Jauh',
    'Enabled' => 'Aktif',
    'Disabled' => 'Tidak aktif',
    'Login:' => 'Nama pengguna :',
    'Full Name:' => 'Nama:',
    'Email:' => 'Emel:',
    'Notifications:' => 'Makluman:',
    'Notifications' => 'Makluman',
    'Account type:' => 'Jenis Akaun :',
    'Edit profile' => 'Sunting profil',
    'Change password' => 'Rubah kata sandri',
    'Password modification' => 'Modifikasi kata laluan',
    'External authentications' => 'Otentifikasi eksternal',
    'Never connected.' => 'Tidak pernah terhubung.',
    'No external authentication enabled.' => 'Tidak ada otentifikasi eksternal yang aktif.',
    'Password modified successfully.' => 'Kata laluan telah berjaya ditukar.',
    'Unable to change the password.' => 'Tidak dapat merubah kata laluanr.',
    'Change category' => 'Tukar kategori',
    '%s updated the task %s' => '%s memperbaharui tugas %s',
    '%s opened the task %s' => '%s membuka tugas %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s memindahkan tugas %s ke posisi n°%d dalam kolom « %s »',
    '%s moved the task %s to the column "%s"' => '%s memindahkan tugas %s ke kolom « %s »',
    '%s created the task %s' => '%s membuat tugas %s',
    '%s closed the task %s' => '%s menutup tugas %s',
    '%s created a subtask for the task %s' => '%s membuat subtugas untuk tugas %s',
    '%s updated a subtask for the task %s' => '%s memperbaharui subtugas untuk tugas %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Ditugaskan untuk %s dengan perkiraan %s/%sh',
    'Not assigned, estimate of %sh' => 'Tiada yang ditugaskan, perkiraan %sh',
    '%s updated a comment on the task %s' => '%s memperbaharui komentar pada tugas %s',
    '%s commented the task %s' => '%s memberikan komentar pada tugas %s',
    '%s\'s activity' => 'Aktifitas dari %s',
    'RSS feed' => 'RSS feed',
    '%s updated a comment on the task #%d' => '%s memperbaharui komentar pada tugas n°%d',
    '%s commented on the task #%d' => '%s memberikan komentar pada tugas n°%d',
    '%s updated a subtask for the task #%d' => '%s memperbaharui subtugas untuk tugas n°%d',
    '%s created a subtask for the task #%d' => '%s membuat subtugas untuk tugas n°%d',
    '%s updated the task #%d' => '%s memperbaharui tugas n°%d',
    '%s created the task #%d' => '%s membuat tugas n°%d',
    '%s closed the task #%d' => '%s menutup tugas n°%d',
    '%s opened the task #%d' => '%s membuka tugas n°%d',
    'Activity' => 'Aktifitas',
    'Default values are "%s"' => 'Standar nilai adalah« %s »',
    'Default columns for new projects (Comma-separated)' => 'Kolom default untuk projek baru (dipisahkan dengan koma)',
    'Task assignee change' => 'Mengubah orang ditugaskan untuk tugas',
    '%s changed the assignee of the task #%d to %s' => '%s rubah orang yang ditugaskan dari tugas n%d ke %s',
    '%s changed the assignee of the task %s to %s' => '%s mengubah orang yang ditugaskan dari tugas %s ke %s',
    'New password for the user "%s"' => 'Kata laluan baru untuk pengguna « %s »',
    'Choose an event' => 'Pilih sebuah acara',
    'Create a task from an external provider' => 'Buat tugas dari pemasok eksternal',
    'Change the assignee based on an external username' => 'Rubah penugasan berdasarkan nama pengguna eksternal',
    'Change the category based on an external label' => 'Rubah kategori berdasarkan label eksternal',
    'Reference' => 'Referensi',
    'Label' => 'Label',
    'Database' => 'Pengkalan data',
    'About' => 'Tentang',
    'Database driver:' => 'Driver pengkalan data:',
    'Board settings' => 'Pengaturan papan',
    'Webhook settings' => 'Penetapan webhook',
    'Reset token' => 'Menetap semula token',
    'API endpoint:' => 'API endpoint :',
    'Refresh interval for personal board' => 'Interval pembaruan untuk papan pribadi',
    'Refresh interval for public board' => 'Interval pembaruan untuk papan publik',
    'Task highlight period' => 'Periode puncak tugas',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periode (dalam detik) untuk mempertimbangkan tugas yang baru dimodifikasi (0 untuk menonaktifkan, standar 2 hari)',
    'Frequency in second (60 seconds by default)' => 'Frequensi dalam detik (standar 60 saat)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekuensi dalam detik (0 untuk menonaktifkan fitur ini, standar 10 detik)',
    'Application URL' => 'URL Aplikasi',
    'Token regenerated.' => 'Token diregenerasi.',
    'Date format' => 'Format tarikh',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Format ISO selalunya diterima, contoh: « %s » et « %s »',
    'New personal project' => 'Projek peribadi baharu',
    'This project is personal' => 'projek ini adalah peribadi',
    'Add' => 'Tambah',
    'Start date' => 'Tarikh mula',
    'Time estimated' => 'Anggaran masa',
    'There is nothing assigned to you.' => 'Tidak ada yang diberikan kepada anda.',
    'My tasks' => 'Tugas saya',
    'Activity stream' => 'Arus aktifitas',
    'Dashboard' => 'Dasbor',
    'Confirmation' => 'Konfirmasi',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Buat komentar dari pemasok eksternal',
    'Project management' => 'Manajemen projek',
    'Columns' => 'Kolom',
    'Task' => 'Tugas',
    'Percentage' => 'Persentasi',
    'Number of tasks' => 'Jumlah dari tugas',
    'Task distribution' => 'Pembagian tugas',
    'Analytics' => 'Analitis',
    'Subtask' => 'Subtugas',
    'User repartition' => 'Partisi ulang pengguna',
    'Clone this project' => 'Gandakan projek ini',
    'Column removed successfully.' => 'Kolom berhasil dihapus.',
    'Not enough data to show the graph.' => 'Tidak cukup data untuk menampilkan grafik.',
    'Previous' => 'Sebelumnya',
    'The id must be an integer' => 'Id harus integer',
    'The project id must be an integer' => 'Id projek harus integer',
    'The status must be an integer' => 'Status harus integer',
    'The subtask id is required' => 'Id subtugas diperlukan',
    'The subtask id must be an integer' => 'Id subtugas harus integer',
    'The task id is required' => 'Id tugas diperlukan',
    'The task id must be an integer' => 'Id tugas harus integer',
    'The user id must be an integer' => 'Id user harus integer',
    'This value is required' => 'Nilai ini diperlukan',
    'This value must be numeric' => 'Nilai ini harus angka',
    'Unable to create this task.' => 'Tidak dapat membuat tugas ini',
    'Cumulative flow diagram' => 'Diagram alir kumulatif',
    'Daily project summary' => 'Ringkasan projek harian',
    'Daily project summary export' => 'Ekspot ringkasan projek harian',
    'Exports' => 'Ekspor',
    'This export contains the number of tasks per column grouped per day.' => 'Ekspor ini berisi jumlah dari tugas per kolom dikelompokan perhari.',
    'Active swimlanes' => 'Swimlanes aktif',
    'Add a new swimlane' => 'Tambah swimlane baharu',
    'Default swimlane' => 'Piawai swimlane',
    'Do you really want to remove this swimlane: "%s"?' => 'Anda yakin untuk menghapus swimlane ini : « %s » ?',
    'Inactive swimlanes' => 'Swimlanes tidak aktif',
    'Remove a swimlane' => 'Padam swimlane',
    'Swimlane modification for the project "%s"' => 'Modifikasi swimlane untuk projek « %s »',
    'Swimlane removed successfully.' => 'Swimlane telah dipadamkan.',
    'Swimlanes' => 'Swimlanes',
    'Swimlane updated successfully.' => 'Swimlane telah dikemaskini.',
    'Unable to remove this swimlane.' => 'Tidak dapat menghapus swimlane ini.',
    'Unable to update this swimlane.' => 'Tidak dapat memperbaharui swimlane ini.',
    'Your swimlane has been created successfully.' => 'Swimlane anda berhasil dibuat.',
    'Example: "Bug, Feature Request, Improvement"' => 'Contoh: « Insiden, Permintaan Ciri, Pembaikan »',
    'Default categories for new projects (Comma-separated)' => 'Piawaian kategori untuk projek baru (asingkan guna koma)',
    'Integrations' => 'Integrasi',
    'Integration with third-party services' => 'Integrasi dengan khidmat pihak ketiga',
    'Subtask Id' => 'Id Subtugas',
    'Subtasks' => 'Subtugas',
    'Subtasks Export' => 'Ekspot Subtugas',
    'Task Title' => 'Judul Tugas',
    'Untitled' => 'Tanpa nama',
    'Application default' => 'Aplikasi Piawaian',
    'Language:' => 'Bahasa:',
    'Timezone:' => 'Zon masa:',
    'All columns' => 'Semua kolom',
    'Next' => 'Selanjutnya',
    '#%d' => 'n°%d',
    'All swimlanes' => 'Semua swimlane',
    'All colors' => 'Semua warna',
    'Moved to column %s' => 'Pindah ke kolom %s',
    'User dashboard' => 'Papan Kenyataan pengguna',
    'Allow only one subtask in progress at the same time for a user' => 'Izinkan hanya satu subtugas dalam proses secara bersamaan untuk satu pengguna',
    'Edit column "%s"' => 'Modifikasi kolom « %s »',
    'Select the new status of the subtask: "%s"' => 'Pilih status baru untuk subtugas : « %s »',
    'Subtask timesheet' => 'Subtugas absen',
    'There is nothing to show.' => 'Tidak ada yang dapat diperlihatkan.',
    'Time Tracking' => 'Pelacakan waktu',
    'You already have one subtask in progress' => 'Anda sudah ada satu subtugas dalam proses',
    'Which parts of the project do you want to duplicate?' => 'Bagian dalam projek mana yang ingin anda duplikasi?',
    'Disallow login form' => 'Larang formulir masuk',
    'Start' => 'Mula',
    'End' => 'Selesai',
    'Task age in days' => 'Usia tugas dalam bentuk harian',
    'Days in this column' => 'Hari dalam kolom ini',
    '%dd' => '%dj',
    'Add a new link' => 'Tambah Pautan baru',
    'Do you really want to remove this link: "%s"?' => 'Anda yakin akan menghapus Pautan ini : « %s » ?',
    'Do you really want to remove this link with task #%d?' => 'Anda yakin akan menghapus Pautan ini dengan tugas n°%d ?',
    'Field required' => 'Medan diperlukan',
    'Link added successfully.' => 'Pautan berhasil ditambahkan.',
    'Link updated successfully.' => 'Pautan berhasil diperbaharui.',
    'Link removed successfully.' => 'Pautan berhasil dihapus.',
    'Link labels' => 'Label Pautan',
    'Link modification' => 'Modifikasi Pautan',
    'Opposite label' => 'Label berlawanan',
    'Remove a link' => 'Hapus Pautan',
    'The labels must be different' => 'Label harus berbeda',
    'There is no link.' => 'Tidak ada Pautan.',
    'This label must be unique' => 'Label ini harus unik',
    'Unable to create your link.' => 'Tidak dapat membuat Pautan anda.',
    'Unable to update your link.' => 'Tidak dapat memperbaharui Pautan anda.',
    'Unable to remove this link.' => 'Tidak dapat menghapus Pautan ini.',
    'relates to' => 'berhubungan dengan',
    'blocks' => 'blok',
    'is blocked by' => 'diblokir oleh',
    'duplicates' => 'duplikat',
    'is duplicated by' => 'diduplikasi oleh',
    'is a child of' => 'anak dari',
    'is a parent of' => 'orant tua dari',
    'targets milestone' => 'milestone target',
    'is a milestone of' => 'adalah milestone dari',
    'fixes' => 'perbaikan',
    'is fixed by' => 'diperbaiki oleh',
    'This task' => 'Tugas ini',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Perluas tugas',
    'Collapse tasks' => 'Lipat tugas',
    'Expand/collapse tasks' => 'Perluas/lipat tugas',
    'Close dialog box' => 'Tutup kotak dialog',
    'Submit a form' => 'Submit formulir',
    'Board view' => 'Table halaman',
    'Keyboard shortcuts' => 'pintas keyboard',
    'Open board switcher' => 'Buka table switcher',
    'Application' => 'Aplikasi',
    'Compact view' => 'Tampilan kompak',
    'Horizontal scrolling' => 'Horisontal bergulir',
    'Compact/wide view' => 'Beralih antara tampilan kompak dan diperluas',
    'Currency' => 'Mata uang',
    'Personal project' => 'projek pribadi',
    'AUD - Australian Dollar' => 'AUD - Dollar Australia',
    'CAD - Canadian Dollar' => 'CAD - Dollar Kanada',
    'CHF - Swiss Francs' => 'CHF - Swiss Prancis',
    'Custom Stylesheet' => 'Kustomisasi Stylesheet',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Poundsterling inggris',
    'INR - Indian Rupee' => 'INR - Rupe India',
    'JPY - Japanese Yen' => 'JPY - Yen Jepang',
    'NZD - New Zealand Dollar' => 'NZD - Dollar Selandia baru',
    'PEN - Peruvian Sol' => 'PEN - Sol Peru',
    'RSD - Serbian dinar' => 'RSD - Dinar Serbia',
    'CNY - Chinese Yuan' => 'CNY - Yuan China',
    'USD - US Dollar' => 'USD - Dollar Amerika',
    'VES - Venezuelan Bolívar' => 'VES - Bolívar Venezuela',
    'Destination column' => 'Kolom tujuan',
    'Move the task to another column when assigned to a user' => 'Pindahkan tugas ke kolom lain ketika ditugaskan ke pengguna',
    'Move the task to another column when assignee is cleared' => 'Pindahkan tugas ke kolom lain ketika orang yang ditugaskan dibersihkan',
    'Source column' => 'Sumber kolom',
    'Transitions' => 'Transisi',
    'Executer' => 'Eksekusi',
    'Time spent in the column' => 'Waktu yang dihabiskan dalam kolom',
    'Task transitions' => 'Transisi tugas',
    'Task transitions export' => 'Ekspor transisi tugas',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Laporan ini berisi semua kolom yang pindah untuk setiap tugas dengan tanggal, pengguna dan waktu yang dihabiskan untuk setiap transisi.',
    'Currency rates' => 'Nilai tukar mata uang',
    'Rate' => 'Tarif',
    'Change reference currency' => 'Mengubah referensi mata uang',
    'Reference currency' => 'Referensi mata uang',
    'The currency rate has been added successfully.' => 'Nilai tukar mata uang berhasil ditambahkan.',
    'Unable to add this currency rate.' => 'Tidak dapat menambahkan nilai tukar mata uang',
    'Webhook URL' => 'URL webhook',
    '%s removed the assignee of the task %s' => '%s menghapus penugasan dari tugas %s',
    'Information' => 'Informasi',
    'Check two factor authentication code' => 'Cek dua faktor kode otentifikasi',
    'The two factor authentication code is not valid.' => 'Kode dua faktor kode otentifikasi tidak valid.',
    'The two factor authentication code is valid.' => 'Kode dua faktor kode otentifikasi valid.',
    'Code' => 'Kode',
    'Two factor authentication' => 'Dua faktor otentifikasi',
    'This QR code contains the key URI: ' => 'kode QR ini mengandung kunci URI : ',
    'Check my code' => 'Memeriksa kode saya',
    'Secret key: ' => 'Kunci rahasia : ',
    'Test your device' => 'Menguji perangkat anda',
    'Assign a color when the task is moved to a specific column' => 'Menetapkan warna ketika tugas tersebut dipindahkan ke kolom tertentu',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Grafik Burndown',
    'This chart show the task complexity over the time (Work Remaining).' => 'Grafik ini menunjukkan kompleksitas tugas dari waktu ke waktu (Sisa Pekerjaan).',
    'Screenshot taken %s' => 'Screenshot diambil %s',
    'Add a screenshot' => 'Tambah screenshot',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Ambil tangkapan skrin dan tekan CTRL+V atau ⌘+V untuk tampal di sini.',
    'Screenshot uploaded successfully.' => 'Screenshot berhasil diunggah.',
    'SEK - Swedish Krona' => 'SEK - Krona Swedia',
    'Identifier' => 'Identifier',
    'Disable two factor authentication' => 'Matikan dua faktor otentifikasi',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Apakah anda yakin akan mematikan dua faktor otentifikasi untuk pengguna ini : « %s » ?',
    'Edit link' => 'Modifikasi Pautan',
    'Start to type task title...' => 'Mulai mengetik judul tugas...',
    'A task cannot be linked to itself' => 'Sebuah tugas tidak dapat dikaitkan dengan dirinya sendiri',
    'The exact same link already exists' => 'Pautan yang sama persis sudah ada',
    'Recurrent task is scheduled to be generated' => 'Tugas berulang dijadwalkan akan dihasilkan',
    'Score' => 'Skor',
    'The identifier must be unique' => 'Identifier harus unik',
    'This linked task id doesn\'t exists' => 'Id tugas terkait tidak ada',
    'This value must be alphanumeric' => 'Nilai harus alfanumerik',
    'Edit recurrence' => 'Modifikasi pengulangan',
    'Generate recurrent task' => 'Menghasilkan tugas berulang',
    'Trigger to generate recurrent task' => 'Memicu untuk menghasilkan tugas berulang',
    'Factor to calculate new due date' => 'Faktor untuk menghitung tanggal jatuh tempo baru',
    'Timeframe to calculate new due date' => 'Jangka waktu untuk menghitung tanggal jatuh tempo baru',
    'Base date to calculate new due date' => 'Tanggal dasar untuk menghitung tanggal jatuh tempo baru',
    'Action date' => 'Tanggal aksi',
    'Base date to calculate new due date: ' => 'Tanggal dasar untuk menghitung tanggal jatuh tempo baru: ',
    'This task has created this child task: ' => 'Tugas ini telah menciptakan tugas anak ini: ',
    'Day(s)' => 'Hari',
    'Existing due date' => 'Batas waktu yang ada',
    'Factor to calculate new due date: ' => 'Faktor untuk menghitung tanggal jatuh tempo baru: ',
    'Month(s)' => 'Bulan',
    'This task has been created by: ' => 'Tugas ini telah dibuat oleh:',
    'Recurrent task has been generated:' => 'Tugas berulang telah dihasilkan:',
    'Timeframe to calculate new due date: ' => 'Jangka waktu untuk menghitung tanggal jatuh tempo baru: ',
    'Trigger to generate recurrent task: ' => 'Pemicu untuk menghasilkan tugas berulang: ',
    'When task is closed' => 'Ketika tugas ditutup',
    'When task is moved from first column' => 'Ketika tugas dipindahkan dari kolom pertama',
    'When task is moved to last column' => 'Ketika tugas dipindahkan ke kolom terakhir',
    'Year(s)' => 'Tahun',
    'Project settings' => 'Pengaturan projek',
    'Automatically update the start date' => 'Otomatikkan pengemaskinian tanggal',
    'iCal feed' => 'iCal feed',
    'Preferences' => 'Keutamaan',
    'Security' => 'Keamanan',
    'Two factor authentication disabled' => 'Otentifikasi dua faktor dimatikan',
    'Two factor authentication enabled' => 'Otentifikasi dua faktor dihidupkan',
    'Unable to update this user.' => 'Tidak dapat memperbarui pengguna ini.',
    'There is no user management for personal projects.' => 'Tidak ada manajemen pengguna untuk projek-projek pribadi.',
    'User that will receive the email' => 'Pengguna yang akan menerima email',
    'Email subject' => 'Subjek Emel',
    'Date' => 'Tanggal',
    'Add a comment log when moving the task between columns' => 'Menambahkan log komentar ketika memindahkan tugas antara kolom',
    'Move the task to another column when the category is changed' => 'Pindahkan tugas ke kolom lain ketika kategori berubah',
    'Send a task by email to someone' => 'Kirim tugas melalui email ke seseorang',
    'Reopen a task' => 'Membuka kembali tugas',
    'Notification' => 'Pemberitahuan',
    '%s moved the task #%d to the first swimlane' => '%s memindahkan tugas n°%d ke swimlane pertama',
    'Swimlane' => 'Swimlane',
    '%s moved the task %s to the first swimlane' => '%s memindahkan tugas %s ke swimlane pertama',
    '%s moved the task %s to the swimlane "%s"' => '%s memindahkan tugas %s ke swimlane « %s »',
    'This report contains all subtasks information for the given date range.' => 'Laporan ini berisi semua informasi subtugas untuk rentang tanggal tertentu.',
    'This report contains all tasks information for the given date range.' => 'Laporan ini berisi semua informasi tugas untuk rentang tanggal tertentu.',
    'Project activities for %s' => 'Aktifitas projek untuk « %s »',
    'view the board on Kanboard' => 'lihat papan di Kanboard',
    'The task has been moved to the first swimlane' => 'Tugas telah dipindahkan ke swimlane pertama',
    'The task has been moved to another swimlane:' => 'Tugas telah dipindahkan ke swimlane lain:',
    'New title: %s' => 'Judul baru : %s',
    'The task is not assigned anymore' => 'Tugas tidak ditugaskan lagi',
    'New assignee: %s' => 'Penerima baru : %s',
    'There is no category now' => 'Tidak ada kategori untuk sekarang',
    'New category: %s' => 'Kategori baru : %s',
    'New color: %s' => 'Warna baru : %s',
    'New complexity: %d' => 'Kompleksitas baru : %d',
    'The due date has been removed' => 'Tanggal jatuh tempo telah dihapus',
    'There is no description anymore' => 'Tidak ada deskripsi lagi',
    'Recurrence settings has been modified' => 'Pengaturan pengulangan telah dimodifikasi',
    'Time spent changed: %sh' => 'Waktu yang dihabiskan berubah : %sh',
    'Time estimated changed: %sh' => 'Perkiraan waktu berubah : %sh',
    'The field "%s" has been updated' => 'Field « %s » telah diperbaharui',
    'The description has been modified:' => 'Deskripsi telah dimodifikasi',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Apakah anda yakin akan menutup tugas « %s » beserta semua sub-tugasnya ?',
    'I want to receive notifications for:' => 'Saya ingin menerima pemberitahuan untuk :',
    'All tasks' => 'Semua tugas',
    'Only for tasks assigned to me' => 'Hanya untuk tugas yang ditugaskan ke saya',
    'Only for tasks created by me' => 'Hanya untuk tugas yang dibuat oleh saya',
    'Only for tasks created by me and tasks assigned to me' => 'Hanya untuk tugas yang dibuat oleh saya dan ditugaskan ke saya',
    '%%Y-%%m-%%d' => '%%d/%%m/%%Y',
    'Total for all columns' => 'Total untuk semua kolom',
    'You need at least 2 days of data to show the chart.' => 'Anda memerlukan setidaknya 2 hari dari data yang menunjukkan grafik.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Hentikan timer',
    'Start timer' => 'Mulai timer',
    'My activity stream' => 'Aliran kegiatan saya',
    'Search tasks' => 'Cari tugas',
    'Reset filters' => 'Reset ulang filter',
    'My tasks due tomorrow' => 'Tugas saya yang berakhir besok',
    'Tasks due today' => 'Tugas yang berakhir hari ini',
    'Tasks due tomorrow' => 'Tugas yang berakhir besok',
    'Tasks due yesterday' => 'Tugas yang berakhir kemarin',
    'Closed tasks' => 'Tugas yang ditutup',
    'Open tasks' => 'Buka Tugas',
    'Not assigned' => 'Tidak ditugaskan',
    'View advanced search syntax' => 'Lihat sintaks pencarian lanjutan',
    'Overview' => 'Ikhtisar',
    'Board/Calendar/List view' => 'Tampilan Papan/Kalender/Daftar',
    'Switch to the board view' => 'Beralih ke tampilan papan',
    'Switch to the list view' => 'Beralih ke tampilan daftar',
    'Go to the search/filter box' => 'Pergi ke kotak pencarian/filter',
    'There is no activity yet.' => 'Tidak ada aktifitas saat ini.',
    'No tasks found.' => 'Tidak ada tugas yang ditemukan.',
    'Keyboard shortcut: "%s"' => 'Keyboard shortcut : « %s »',
    'List' => 'Daftar',
    'Filter' => 'Filter',
    'Advanced search' => 'Pencarian lanjutan',
    'Example of query: ' => 'Contoh dari query : ',
    'Search by project: ' => 'Pencarian berdasarkan projek : ',
    'Search by column: ' => 'Pencarian berdasarkan kolom : ',
    'Search by assignee: ' => 'Pencarian berdasarkan penerima : ',
    'Search by color: ' => 'Pencarian berdasarkan warna : ',
    'Search by category: ' => 'Pencarian berdasarkan kategori : ',
    'Search by description: ' => 'Pencarian berdasarkan deskripsi : ',
    'Search by due date: ' => 'Pencarian berdasarkan tanggal jatuh tempo : ',
    'Average time spent in each column' => 'Rata-rata waktu yang dihabiskan dalam setiap kolom',
    'Average time spent' => 'Rata-rata waktu yang dihabiskan',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Grafik ini menunjukkan rata-rata waktu yang dihabiskan dalam setiap kolom untuk %d tugas.',
    'Average Lead and Cycle time' => 'Rata-rata Memimpin dan Siklus waktu',
    'Average lead time: ' => 'Rata-rata waktu pimpinan : ',
    'Average cycle time: ' => 'Rata-rata siklus waktu : ',
    'Cycle Time' => 'Siklus Waktu',
    'Lead Time' => 'Lead Time',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Grafik ini menunjukkan memimpin rata-rata dan waktu siklus untuk %d tugas terakhir dari waktu ke waktu.',
    'Average time into each column' => 'Rata-rata waktu ke setiap kolom',
    'Lead and cycle time' => 'Lead dan siklus waktu',
    'Lead time: ' => 'Lead time : ',
    'Cycle time: ' => 'Siklus waktu : ',
    'Time spent in each column' => 'Waktu yang dihabiskan di setiap kolom',
    'The lead time is the duration between the task creation and the completion.' => 'Lead time adalah durasi antara pembuatan tugas dan penyelesaian.',
    'The cycle time is the duration between the start date and the completion.' => 'Siklus waktu adalah durasi antara tanggal mulai dan tanggal penyelesaian.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Jika tugas tidak ditutup waktu saat ini yang digunakan sebagai pengganti tanggal penyelesaian.',
    'Set the start date automatically' => 'Secara otomatis mengatur tanggal mulai',
    'Edit Authentication' => 'Modifikasi Otentifikasi',
    'Remote user' => 'Pengguna jauh',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Pengguna jauh tidak menyimpan kata laluan mereka dalam basis data Kanboard, contoh: Akaun LDAP, Google dan Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Jika anda mencentang kotak "Larang formulir login", kredensial masuk ke formulis login akan diabaikan.',
    'Default task color' => 'Standar warna tugas',
    'This feature does not work with all browsers.' => 'Ciri ini tidak dapat digunakan pada semua browsers',
    'There is no destination project available.' => 'Tiada destinasi projek yang tersedia.',
    'Trigger automatically subtask time tracking' => 'Picu pengesanan subtugas secara otomatik',
    'Include closed tasks in the cumulative flow diagram' => 'Termasuk tugas yang ditutup pada diagram aliran kumulatif',
    'Current swimlane: %s' => 'Swimlane saat ini : %s',
    'Current column: %s' => 'Kolom saat ini : %s',
    'Current category: %s' => 'Kategori saat ini : %s',
    'no category' => 'tiada kategori',
    'Current assignee: %s' => 'Saat ini ditugaskan pada: %s',
    'not assigned' => 'Belum ditugaskan',
    'Author:' => 'Penulis:',
    'contributors' => 'Penggiat',
    'License:' => 'Lesen:',
    'License' => 'Lesen',
    'Enter the text below' => 'Masukkan teks di bawah',
    'Start date:' => 'Tanggal mulai:',
    'Due date:' => 'Batas waktu:',
    'People who are project managers' => 'Orang-orang yang menjadi pengurus projek',
    'People who are project members' => 'Orang-orang yang menjadi anggota projek',
    'NOK - Norwegian Krone' => 'NOK - Krone Norwegia',
    'Show this column' => 'Perlihatkan kolom ini',
    'Hide this column' => 'Sembunyikan kolom ini',
    'End date' => 'Waktu berakhir',
    'Users overview' => 'Ikhtisar pengguna',
    'Members' => 'Anggota',
    'Shared project' => 'projek bersama',
    'Project managers' => 'Pengurus projek',
    'Projects list' => 'Senarai projek',
    'End date:' => 'Waktu berakhir :',
    'Change task color when using a specific task link' => 'Rubah warna tugas ketika menggunakan Pautan tugas yang spesifik',
    'Task link creation or modification' => 'Pautan tugas pada penciptaan atau penyuntingan',
    'Milestone' => 'Batu Tanda',
    'Reset the search/filter box' => 'Tetap semula pencarian/saringan',
    'Documentation' => 'Dokumentasi',
    'Author' => 'Pengarang',
    'Version' => 'Versi',
    'Plugins' => 'Plugin',
    'There is no plugin loaded.' => 'Tiada plugin yang dimuat.',
    'My notifications' => 'Notifikasi saya',
    'Custom filters' => 'Penapis kustom',
    'Your custom filter has been created successfully.' => 'Penapis kustom anda telah berjaya dicipta.',
    'Unable to create your custom filter.' => 'Tidak dapat mencipta penapis kustom anda.',
    'Custom filter removed successfully.' => 'Penapis kustom berjaya dibuang.',
    'Unable to remove this custom filter.' => 'Tidak dapat membuang penapis kustom ini.',
    'Edit custom filter' => 'Edit penapis kustom',
    'Your custom filter has been updated successfully.' => 'Penapis kustom anda telah berjaya dikemas kini.',
    'Unable to update custom filter.' => 'Tidak dapat mengemaskini penapis kustom.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Lampiran baru pada tugas #%d: %s',
    'New comment on task #%d' => 'Komen baru pada tugas #%d',
    'Comment updated on task #%d' => 'Komen dikemas kini pada tugas #%d',
    'New subtask on task #%d' => 'Subtugas baru pada tugas #%d',
    'Subtask updated on task #%d' => 'Subtugas dikemas kini pada tugas #%d',
    'New task #%d: %s' => 'Tugas baru #%d: %s',
    'Task updated #%d' => 'Tugas dikemas kini #%d',
    'Task #%d closed' => 'Tugas #%d ditutup',
    'Task #%d opened' => 'Tugas #%d dibuka',
    'Column changed for task #%d' => 'Lajur diubah untuk tugas #%d',
    'New position for task #%d' => 'Kedudukan baru untuk tugas #%d',
    'Swimlane changed for task #%d' => 'Swimlane diubah untuk tugas #%d',
    'Assignee changed on task #%d' => 'Penerima tugas diubah pada tugas #%d',
    '%d overdue tasks' => '%d tugas tertunggak',
    'No notification.' => 'Tiada notifikasi.',
    'Mark all as read' => 'Tandakan semua sebagai dibaca',
    'Mark as read' => 'Tandakan sebagai dibaca',
    'Total number of tasks in this column across all swimlanes' => 'Jumlah tugas dalam lajur ini merentasi semua swimlane',
    'Collapse swimlane' => 'Lipat swimlane',
    'Expand swimlane' => 'Kembangkan swimlane',
    'Add a new filter' => 'Tambah penapis baru',
    'Share with all project members' => 'Kongsi dengan semua ahli projek',
    'Shared' => 'Dikongsi',
    'Owner' => 'Pemilik',
    'Unread notifications' => 'Notifikasi belum dibaca',
    'Notification methods:' => 'Kaedah notifikasi:',
    'Unable to read your file' => 'Tidak dapat membaca fail anda',
    '%d task(s) have been imported successfully.' => '%d tugas telah berjaya diimport.',
    'Nothing has been imported!' => 'Tiada yang diimport!',
    'Import users from CSV file' => 'Import pengguna dari fail CSV',
    '%d user(s) have been imported successfully.' => '%d pengguna telah berjaya diimport.',
    'Comma' => 'Koma',
    'Semi-colon' => 'Koma bertitik',
    'Tab' => 'Tab',
    'Vertical bar' => 'Bar menegak',
    'Double Quote' => 'Tanda Petik Ganda',
    'Single Quote' => 'Tanda Petik Tunggal',
    '%s attached a file to the task #%d' => '%s melampirkan fail ke tugas #%d',
    'There is no column or swimlane activated in your project!' => 'Tiada lajur atau swimlane yang diaktifkan dalam projek anda!',
    'Append filter (instead of replacement)' => 'Tambah penapis (bukannya penggantian)',
    'Append/Replace' => 'Tambah/Ganti',
    'Append' => 'Tambah',
    'Replace' => 'Ganti',
    'Import' => 'Import',
    'Change sorting' => 'Ubah susunan',
    'Tasks Importation' => 'Pengimportan Tugas',
    'Delimiter' => 'Pembatas',
    'Enclosure' => 'Penutup',
    'CSV File' => 'Fail CSV',
    'Instructions' => 'Arahan',
    'Your file must use the predefined CSV format' => 'Fail anda mesti menggunakan format CSV yang telah ditentukan',
    'Your file must be encoded in UTF-8' => 'Fail anda mesti dikodkan dalam UTF-8',
    'The first row must be the header' => 'Baris pertama mestilah tajuk',
    'Duplicates are not verified for you' => 'Pendua tidak disahkan untuk anda',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Tarikh tamat tempoh mesti menggunakan format ISO: YYYY-MM-DD',
    'Download CSV template' => 'Muat turun templat CSV',
    'No external integration registered.' => 'Tiada integrasi luaran yang berdaftar.',
    'Duplicates are not imported' => 'Pendua tidak diimport',
    'Usernames must be lowercase and unique' => 'Nama pengguna mestilah huruf kecil dan unik',
    'Passwords will be encrypted if present' => 'Kata laluan akan disulitkan jika ada',
    '%s attached a new file to the task %s' => '%s melampirkan fail baru ke tugas %s',
    'Link type' => 'Jenis pautan',
    'Assign automatically a category based on a link' => 'Tetapkan kategori secara automatik berdasarkan pautan',
    'BAM - Konvertible Mark' => 'BAM - Mark Boleh Tukar',
    'Assignee Username' => 'Nama Pengguna Penerima Tugas',
    'Assignee Name' => 'Nama Penerima Tugas',
    'Groups' => 'Kumpulan',
    'Members of %s' => 'Ahli %s',
    'New group' => 'Kumpulan baru',
    'Group created successfully.' => 'Kumpulan berjaya dicipta.',
    'Unable to create your group.' => 'Tidak dapat mencipta kumpulan anda.',
    'Edit group' => 'Edit kumpulan',
    'Group updated successfully.' => 'Kumpulan berjaya dikemas kini.',
    'Unable to update your group.' => 'Tidak dapat mengemaskini kumpulan anda.',
    'Add group member to "%s"' => 'Tambah ahli kumpulan ke "%s"',
    'Group member added successfully.' => 'Ahli kumpulan berjaya ditambah.',
    'Unable to add group member.' => 'Tidak dapat menambah ahli kumpulan.',
    'Remove user from group "%s"' => 'Buang pengguna dari kumpulan "%s"',
    'User removed successfully from this group.' => 'Pengguna berjaya dibuang dari kumpulan ini.',
    'Unable to remove this user from the group.' => 'Tidak dapat membuang pengguna ini dari kumpulan.',
    'Remove group' => 'Buang kumpulan',
    'Group removed successfully.' => 'Kumpulan berjaya dibuang.',
    'Unable to remove this group.' => 'Tidak dapat membuang kumpulan ini.',
    'Project Permissions' => 'Kebenaran Projek',
    'Manager' => 'Pengurus',
    'Project Manager' => 'Pengurus Projek',
    'Project Member' => 'Ahli Projek',
    'Project Viewer' => 'Penonton Projek',
    'Your account is locked for %d minutes' => 'Akaun anda dikunci selama %d minit',
    'Invalid captcha' => 'Captcha tidak sah',
    'The name must be unique' => 'Nama mestilah unik',
    'View all groups' => 'Lihat semua kumpulan',
    'There is no user available.' => 'Tiada pengguna yang tersedia.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Adakah anda benar-benar mahu membuang pengguna "%s" dari kumpulan "%s"?',
    'There is no group.' => 'Tiada kumpulan.',
    'Add group member' => 'Tambah ahli kumpulan',
    'Do you really want to remove this group: "%s"?' => 'Adakah anda benar-benar mahu membuang kumpulan ini: "%s"?',
    'There is no user in this group.' => 'Tiada pengguna dalam kumpulan ini.',
    'Permissions' => 'Kebenaran',
    'Allowed Users' => 'Pengguna Dibenarkan',
    'No specific user has been allowed.' => 'Tiada pengguna tertentu yang dibenarkan.',
    'Role' => 'Peranan',
    'Enter user name...' => 'Masukkan nama pengguna...',
    'Allowed Groups' => 'Kumpulan Dibenarkan',
    'No group has been allowed.' => 'Tiada kumpulan yang dibenarkan.',
    'Group' => 'Kumpulan',
    'Group Name' => 'Nama Kumpulan',
    'Enter group name...' => 'Masukkan nama kumpulan...',
    'Role:' => 'Peranan',
    'Project members' => 'Anggota projek',
    '%s mentioned you in the task #%d' => '%s menyebut anda dalam tugas #%d',
    '%s mentioned you in a comment on the task #%d' => '%s menyebut anda dalam komen pada tugas #%d',
    'You were mentioned in the task #%d' => 'Anda disebut dalam tugas #%d',
    'You were mentioned in a comment on the task #%d' => 'Anda disebut dalam komen pada tugas #%d',
    'Estimated hours: ' => 'Anggaran jam: ',
    'Actual hours: ' => 'Jam sebenar: ',
    'Hours Spent' => 'Jam Dihabiskan',
    'Hours Estimated' => 'Jam Dianggarkan',
    'Estimated Time' => 'Masa Dianggarkan',
    'Actual Time' => 'Masa Sebenar',
    'Estimated vs actual time' => 'Masa anggaran vs sebenar',
    'RUB - Russian Ruble' => 'RUB - Rubel Rusia',
    'Assign the task to the person who does the action when the column is changed' => 'Tetapkan tugas kepada orang yang melakukan tindakan apabila lajur diubah',
    'Close a task in a specific column' => 'Tutup tugas dalam lajur tertentu',
    'Time-based One-time Password Algorithm' => 'Algoritma Kata Laluan Satu Kali Berasaskan Masa',
    'Two-Factor Provider: ' => 'Pembekal Dua Faktor: ',
    'Disable two-factor authentication' => 'Nyahaktifkan pengesahan dua faktor',
    'Enable two-factor authentication' => 'Aktifkan pengesahan dua faktor',
    'There is no integration registered at the moment.' => 'Tiada integrasi yang berdaftar pada masa ini.',
    'Password Reset for Kanboard' => 'Tetapan Semula Kata Laluan untuk Kanboard',
    'Forgot password?' => 'Lupa kata laluan?',
    'Enable "Forget Password"' => 'Aktifkan "Lupa Kata Laluan"',
    'Password Reset' => 'Tetapan Semula Kata Laluan',
    'New password' => 'Kata laluan baru',
    'Change Password' => 'Tukar Kata Laluan',
    'To reset your password click on this link:' => 'Untuk menetapkan semula kata laluan anda klik pada pautan ini:',
    'Last Password Reset' => 'Tetapan Semula Kata Laluan Terakhir',
    'The password has never been reinitialized.' => 'Kata laluan tidak pernah ditetapkan semula.',
    'Creation' => 'Ciptaan',
    'Expiration' => 'Jangka hayat',
    'Password reset history' => 'Sirah tetap semula kata laluan',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Semua tugas dalam lajur "%s" dan swimlane "%s" telah berjaya ditutup.',
    'Do you really want to close all tasks of this column?' => 'Adakah anda benar-benar mahu menutup semua tugas dalam lajur ini?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tugas dalam lajur "%s" dan swimlane "%s" akan ditutup.',
    'Close all tasks in this column and this swimlane' => 'Tutup semua tugas dalam lajur ini dan swimlane ini',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Tiada plugin yang mendaftarkan kaedah notifikasi projek. Anda masih boleh mengkonfigurasi notifikasi individu dalam profil pengguna anda.',
    'My dashboard' => 'Papan pemuka saya',
    'My profile' => 'Profil saya',
    'Project owner: ' => 'Pemilik projek: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Pengecam projek adalah pilihan dan mesti alfanumerik, contoh: PROJEKSAYA.',
    'Project owner' => 'Pemilik projek',
    'Personal projects do not have users and groups management.' => 'Projek peribadi tidak mempunyai pengurusan pengguna dan kumpulan.',
    'There is no project member.' => 'Tiada ahli projek.',
    'Priority' => 'Keutamaan',
    'Task priority' => 'Keutamaan tugas',
    'General' => 'Umum',
    'Dates' => 'Tarikh',
    'Default priority' => 'Keutamaan lalai',
    'Lowest priority' => 'Keutamaan terendah',
    'Highest priority' => 'Keutamaan tertinggi',
    'Close a task when there is no activity' => 'Tutup tugas apabila tiada aktiviti',
    'Duration in days' => 'Tempoh dalam hari',
    'Send email when there is no activity on a task' => 'Hantar e-mel apabila tiada aktiviti pada tugas',
    'Unable to fetch link information.' => 'Tidak dapat mengambil maklumat pautan.',
    'Daily background job for tasks' => 'Tugasan latar belakang harian untuk tugas',
    'Auto' => 'Auto',
    'Related' => 'Berkaitan',
    'Attachment' => 'Lampiran',
    'Web Link' => 'Pautan Web',
    'External links' => 'Pautan luaran',
    'Add external link' => 'Tambah pautan luaran',
    'Type' => 'Jenis',
    'Dependency' => 'Kebergantungan',
    'Add internal link' => 'Tambah pautan dalaman',
    'Add a new external link' => 'Tambah pautan luaran baru',
    'Edit external link' => 'Edit pautan luaran',
    'External link' => 'Pautan luaran',
    'Copy and paste your link here...' => 'Salin dan tampal pautan anda di sini...',
    'URL' => 'URL',
    'Internal links' => 'Pautan dalaman',
    'Assign to me' => 'Tetapkan kepada saya',
    'Me' => 'Saya',
    'Do not duplicate anything' => 'Jangan pendua apa-apa',
    'Projects management' => 'Pengurusan projek',
    'Users management' => 'Pengurusan pengguna',
    'Groups management' => 'Pengurusan kumpulan',
    'Create from another project' => 'Cipta dari projek lain',
    'open' => 'terbuka',
    'closed' => 'ditutup',
    'Priority:' => 'Keutamaan:',
    'Reference:' => 'Rujukan:',
    'Complexity:' => 'Kerumitan:',
    'Swimlane:' => 'Swimlane:',
    'Column:' => 'Lajur:',
    'Position:' => 'Kedudukan:',
    'Creator:' => 'Pencipta:',
    'Time estimated:' => 'Masa dianggarkan:',
    '%s hours' => '%s jam',
    'Time spent:' => 'Masa dihabiskan:',
    'Created:' => 'Dicipta:',
    'Modified:' => 'Diubah suai:',
    'Completed:' => 'Selesai:',
    'Started:' => 'Dimulakan:',
    'Moved:' => 'Dipindahkan:',
    'Task #%d' => 'Tugas #%d',
    'Time format' => 'Format masa',
    'Start date: ' => 'Tarikh mula: ',
    'End date: ' => 'Tarikh tamat: ',
    'New due date: ' => 'Tarikh tamat tempoh baru: ',
    'Start date changed: ' => 'Tarikh mula diubah: ',
    'Disable personal projects' => 'Nyahaktifkan projek peribadi',
    'Do you really want to remove this custom filter: "%s"?' => 'Adakah anda benar-benar mahu membuang penapis kustom ini: "%s"?',
    'Remove a custom filter' => 'Buang penapis kustom',
    'User activated successfully.' => 'Pengguna berjaya diaktifkan.',
    'Unable to enable this user.' => 'Tidak dapat mengaktifkan pengguna ini.',
    'User disabled successfully.' => 'Pengguna berjaya dinyahaktifkan.',
    'Unable to disable this user.' => 'Tidak dapat menyahaktifkan pengguna ini.',
    'All files have been uploaded successfully.' => 'Semua fail telah berjaya dimuat naik.',
    'The maximum allowed file size is %sB.' => 'Saiz fail maksimum yang dibenarkan ialah %sB.',
    'Drag and drop your files here' => 'Seret dan lepaskan fail anda di sini',
    'choose files' => 'pilih fail',
    'View profile' => 'Lihat profil',
    'Two Factor' => 'Dua Faktor',
    'Disable user' => 'Nyahaktifkan pengguna',
    'Do you really want to disable this user: "%s"?' => 'Adakah anda benar-benar mahu menyahaktifkan pengguna ini: "%s"?',
    'Enable user' => 'Aktifkan pengguna',
    'Do you really want to enable this user: "%s"?' => 'Adakah anda benar-benar mahu mengaktifkan pengguna ini: "%s"?',
    'Download' => 'Muat turun',
    'Uploaded: %s' => 'Dimuat naik: %s',
    'Size: %s' => 'Saiz: %s',
    'Uploaded by %s' => 'Dimuat naik oleh %s',
    'Filename' => 'Nama fail',
    'Size' => 'Saiz',
    'Column created successfully.' => 'Lajur berjaya dicipta.',
    'Another column with the same name exists in the project' => 'Lajur lain dengan nama yang sama wujud dalam projek',
    'Default filters' => 'Penapis lalai',
    'Your board doesn\'t have any columns!' => 'Papan anda tidak mempunyai sebarang lajur!',
    'Change column position' => 'Ubah kedudukan lajur',
    'Switch to the project overview' => 'Beralih ke gambaran keseluruhan projek',
    'User filters' => 'Penapis pengguna',
    'Category filters' => 'Penapis kategori',
    'Upload a file' => 'Muat naik fail',
    'View file' => 'Lihat fail',
    'Last activity' => 'Aktiviti terakhir',
    'Change subtask position' => 'Ubah kedudukan subtugas',
    'This value must be greater than %d' => 'Nilai ini mestilah lebih besar daripada %d',
    'Another swimlane with the same name exists in the project' => 'Swimlane lain dengan nama yang sama wujud dalam projek',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Contoh: https://example.kanboard.org/ (digunakan untuk menjana URL mutlak)',
    'Actions duplicated successfully.' => 'Tindakan berjaya diduplikat.',
    'Unable to duplicate actions.' => 'Tidak dapat menduplikat tindakan.',
    'Add a new action' => 'Tambah tindakan baru',
    'Import from another project' => 'Import dari projek lain',
    'There is no action at the moment.' => 'Tiada tindakan pada masa ini.',
    'Import actions from another project' => 'Import tindakan dari projek lain',
    'There is no available project.' => 'Tiada projek yang tersedia.',
    'Local File' => 'Fail Tempatan',
    'Configuration' => 'Konfigurasi',
    'PHP version:' => 'Versi PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versi OS:',
    'Database version:' => 'Versi pangkalan data:',
    'Browser:' => 'Pelayar:',
    'Task view' => 'Paparan tugas',
    'Edit task' => 'Edit tugas',
    'Edit description' => 'Edit penerangan',
    'New internal link' => 'Pautan dalaman baru',
    'Display list of keyboard shortcuts' => 'Papar senarai pintasan papan kekunci',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Muat naik imej avatar saya',
    'Remove my image' => 'Buang imej saya',
    'The OAuth2 state parameter is invalid' => 'Parameter keadaan OAuth2 tidak sah',
    'User not found.' => 'Pengguna tidak dijumpai.',
    'Search in activity stream' => 'Cari dalam aliran aktiviti',
    'My activities' => 'Aktiviti saya',
    'Activity until yesterday' => 'Aktiviti sehingga semalam',
    'Activity until today' => 'Aktiviti sehingga hari ini',
    'Search by creator: ' => 'Cari mengikut pencipta: ',
    'Search by creation date: ' => 'Cari mengikut tarikh cipta: ',
    'Search by task status: ' => 'Cari mengikut status tugas: ',
    'Search by task title: ' => 'Cari mengikut tajuk tugas: ',
    'Activity stream search' => 'Carian aliran aktiviti',
    'Projects where "%s" is manager' => 'Projek di mana "%s" adalah pengurus',
    'Projects where "%s" is member' => 'Projek di mana "%s" adalah ahli',
    'Open tasks assigned to "%s"' => 'Tugas terbuka yang ditetapkan kepada "%s"',
    'Closed tasks assigned to "%s"' => 'Tugas tertutup yang ditetapkan kepada "%s"',
    'Assign automatically a color based on a priority' => 'Tetapkan warna secara automatik berdasarkan keutamaan',
    'Overdue tasks for the project(s) "%s"' => 'Tugas terlambat untuk projek « %s »',
    'Upload files' => 'Muat naik fail',
    'Installed Plugins' => 'Plugin yang Dipasang',
    'Plugin Directory' => 'Direktori Plugin',
    'Plugin installed successfully.' => 'Plugin berjaya dipasang.',
    'Plugin updated successfully.' => 'Plugin berjaya dikemas kini.',
    'Plugin removed successfully.' => 'Plugin berjaya dibuang.',
    'Subtask converted to task successfully.' => 'Subtugas berjaya ditukar kepada tugas.',
    'Unable to convert the subtask.' => 'Tidak dapat menukar subtugas.',
    'Unable to extract plugin archive.' => 'Tidak dapat mengekstrak arkib plugin.',
    'Plugin not found.' => 'Plugin tidak dijumpai.',
    'You don\'t have the permission to remove this plugin.' => 'Anda tidak mempunyai kebenaran untuk membuang plugin ini.',
    'Unable to download plugin archive.' => 'Tidak dapat memuat turun arkib plugin.',
    'Unable to write temporary file for plugin.' => 'Tidak dapat menulis fail sementara untuk plugin.',
    'Unable to open plugin archive.' => 'Tidak dapat membuka arkib plugin.',
    'There is no file in the plugin archive.' => 'Tiada fail dalam arkib plugin.',
    'Create tasks in bulk' => 'Cipta tugas secara pukal',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Instans Kanboard anda tidak dikonfigurasi untuk memasang plugin dari antara muka pengguna.',
    'There is no plugin available.' => 'Tiada plugin yang tersedia.',
    'Install' => 'Pasang',
    'Update' => 'Kemas kini',
    'Up to date' => 'Terkini',
    'Not available' => 'Tidak tersedia',
    'Remove plugin' => 'Buang plugin',
    'Do you really want to remove this plugin: "%s"?' => 'Adakah anda benar-benar mahu membuang plugin ini: "%s"?',
    'Uninstall' => 'Nyahpasang',
    'Listing' => 'Penyenaraian',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Urus projek',
    'Convert to task' => 'Tukar kepada tugas',
    'Convert sub-task to task' => 'Tukar sub-tugas kepada tugas',
    'Do you really want to convert this sub-task to a task?' => 'Adakah anda benar-benar mahu menukar sub-tugas ini kepada tugas?',
    'My task title' => 'Tajuk tugas saya',
    'Enter one task by line.' => 'Masukkan satu tugas setiap baris.',
    'Number of failed login:' => 'Bilangan log masuk gagal:',
    'Account locked until:' => 'Akaun dikunci sehingga:',
    'Email settings' => 'Tetapan e-mel',
    'Email sender address' => 'Alamat penghantar e-mel',
    'Email transport' => 'Pengangkutan e-mel',
    'Webhook token' => 'Token webhook',
    'Project tags management' => 'Pengurusan tag projek',
    'Tag created successfully.' => 'Tag berjaya dicipta.',
    'Unable to create this tag.' => 'Tidak dapat mencipta tag ini.',
    'Tag updated successfully.' => 'Tag berjaya dikemas kini.',
    'Unable to update this tag.' => 'Tidak dapat mengemaskini tag ini.',
    'Tag removed successfully.' => 'Tag berjaya dibuang.',
    'Unable to remove this tag.' => 'Tidak dapat membuang tag ini.',
    'Global tags management' => 'Pengurusan tag global',
    'Tags' => 'Tag',
    'Tags management' => 'Pengurusan tag',
    'Add new tag' => 'Tambah tag baru',
    'Edit a tag' => 'Edit tag',
    'Project tags' => 'Tag projek',
    'There is no specific tag for this project at the moment.' => 'Tiada tag khusus untuk projek ini pada masa ini.',
    'Tag' => 'Tag',
    'Remove a tag' => 'Buang tag',
    'Do you really want to remove this tag: "%s"?' => 'Adakah anda benar-benar mahu membuang tag ini: "%s"?',
    'Global tags' => 'Tag global',
    'There is no global tag at the moment.' => 'Tiada tag global pada masa ini.',
    'This field cannot be empty' => 'Medan ini tidak boleh kosong',
    'Close a task when there is no activity in a specific column' => 'Tutup tugas apabila tiada aktiviti dalam lajur tertentu',
    '%s removed a subtask for the task #%d' => '%s membuang subtugas untuk tugas #%d',
    '%s removed a comment on the task #%d' => '%s membuang komen pada tugas #%d',
    'Comment removed on task #%d' => 'Komen dibuang pada tugas #%d',
    'Subtask removed on task #%d' => 'Subtugas dibuang pada tugas #%d',
    'Hide tasks in this column in the dashboard' => 'Sembunyikan tugas dalam lajur ini di papan pemuka',
    '%s removed a comment on the task %s' => '%s membuang komen pada tugas %s',
    '%s removed a subtask for the task %s' => '%s membuang subtugas untuk tugas %s',
    'Comment removed' => 'Komen dibuang',
    'Subtask removed' => 'Subtugas dibuang',
    '%s set a new internal link for the task #%d' => '%s menetapkan pautan dalaman baru untuk tugas #%d',
    '%s removed an internal link for the task #%d' => '%s membuang pautan dalaman untuk tugas #%d',
    'A new internal link for the task #%d has been defined' => 'Pautan dalaman baru untuk tugas #%d telah ditentukan',
    'Internal link removed for the task #%d' => 'Pautan dalaman dibuang untuk tugas #%d',
    '%s set a new internal link for the task %s' => '%s menetapkan pautan dalaman baru untuk tugas %s',
    '%s removed an internal link for the task %s' => '%s membuang pautan dalaman untuk tugas %s',
    'Automatically set the due date on task creation' => 'Tetapkan tarikh tamat tempoh secara automatik semasa penciptaan tugas',
    'Move the task to another column when closed' => 'Pindahkan tugas ke lajur lain apabila ditutup',
    'Move the task to another column when not moved during a given period' => 'Pindahkan tugas ke lajur lain apabila tidak dipindahkan dalam tempoh yang diberikan',
    'Dashboard for %s' => 'Papan pemuka untuk %s',
    'Tasks overview for %s' => 'Gambaran keseluruhan tugas untuk %s',
    'Subtasks overview for %s' => 'Gambaran keseluruhan subtugas untuk %s',
    'Projects overview for %s' => 'Gambaran keseluruhan projek untuk %s',
    'Activity stream for %s' => 'Strim aktiviti untuk %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Berikan warna apabila tugas dipindahkan ke lajur tertentu',
    'Assign a priority when the task is moved to a specific swimlane' => 'Berikan keutamaan apabila tugas dipindahkan ke lajur tertentu',
    'User unlocked successfully.' => 'Pengguna berjaya dinyahkunci.',
    'Unable to unlock the user.' => 'Tidak dapat menyahkunci pengguna.',
    'Move a task to another swimlane' => 'Pindahkan tugas ke lajur lain',
    'Creator Name' => 'Nama Pencipta',
    'Time spent and estimated' => 'Masa yang dihabiskan dan dianggarkan',
    'Move position' => 'Alih kedudukan',
    'Move task to another position on the board' => 'Pindahkan tugas ke kedudukan lain pada papan',
    'Insert before this task' => 'Sisipkan sebelum tugas ini',
    'Insert after this task' => 'Sisipkan selepas tugas ini',
    'Unlock this user' => 'Nyahkunci pengguna ini',
    'Custom Project Roles' => 'Peranan Projek Tersuai',
    'Add a new custom role' => 'Tambah peranan tersuai baharu',
    'Restrictions for the role "%s"' => 'Sekatan untuk peranan "%s"',
    'Add a new project restriction' => 'Tambah sekatan projek baharu',
    'Add a new drag and drop restriction' => 'Tambah sekatan seret dan lepas baharu',
    'Add a new column restriction' => 'Tambah sekatan lajur baharu',
    'Edit this role' => 'Edit peranan ini',
    'Remove this role' => 'Alih keluar peranan ini',
    'There is no restriction for this role.' => 'Tiada sekatan untuk peranan ini.',
    'Only moving task between those columns is permitted' => 'Hanya memindahkan tugas antara lajur tersebut dibenarkan',
    'Close a task in a specific column when not moved during a given period' => 'Tutup tugas dalam lajur tertentu apabila tidak dipindahkan dalam tempoh yang diberikan',
    'Edit columns' => 'Edit lajur',
    'The column restriction has been created successfully.' => 'Sekatan lajur telah berjaya dicipta.',
    'Unable to create this column restriction.' => 'Tidak dapat mencipta sekatan lajur ini.',
    'Column restriction removed successfully.' => 'Sekatan lajur berjaya dialih keluar.',
    'Unable to remove this restriction.' => 'Tidak dapat mengalih keluar sekatan ini.',
    'Your custom project role has been created successfully.' => 'Peranan projek tersuai anda berjaya dicipta.',
    'Unable to create custom project role.' => 'Tidak dapat mencipta peranan projek tersuai.',
    'Your custom project role has been updated successfully.' => 'Peranan projek tersuai anda berjaya dikemas kini.',
    'Unable to update custom project role.' => 'Tidak dapat mengemas kini peranan projek tersuai.',
    'Custom project role removed successfully.' => 'Peranan projek tersuai berjaya dialih keluar.',
    'Unable to remove this project role.' => 'Tidak dapat mengalih keluar peranan projek ini.',
    'The project restriction has been created successfully.' => 'Sekatan projek telah berjaya dicipta.',
    'Unable to create this project restriction.' => 'Tidak dapat mencipta sekatan projek ini.',
    'Project restriction removed successfully.' => 'Sekatan projek berjaya dialih keluar.',
    'You cannot create tasks in this column.' => 'Anda tidak dapat mencipta tugas dalam lajur ini.',
    'Task creation is permitted for this column' => 'Penciptaan tugas dibenarkan untuk lajur ini',
    'Closing or opening a task is permitted for this column' => 'Menutup atau membuka tugas dibenarkan untuk lajur ini',
    'Task creation is blocked for this column' => 'Penciptaan tugas disekat untuk lajur ini',
    'Closing or opening a task is blocked for this column' => 'Menutup atau membuka tugas disekat untuk lajur ini',
    'Task creation is not permitted' => 'Penciptaan tugas tidak dibenarkan',
    'Closing or opening a task is not permitted' => 'Menutup atau membuka tugas tidak dibenarkan',
    'New drag and drop restriction for the role "%s"' => 'Sekatan seret dan lepas baharu untuk peranan "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Orang yang mempunyai peranan ini hanya boleh memindahkan tugas antara lajur sumber dan destinasi.',
    'Remove a column restriction' => 'Alih keluar sekatan lajur',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Adakah anda benar-benar mahu mengalih keluar sekatan lajur ini: "%s" ke "%s"?',
    'New column restriction for the role "%s"' => 'Sekatan lajur baharu untuk peranan "%s"',
    'Rule' => 'Peraturan',
    'Do you really want to remove this column restriction?' => 'Adakah anda benar-benar mahu mengalih keluar sekatan lajur ini?',
    'Custom roles' => 'Peranan tersuai',
    'New custom project role' => 'Peranan projek tersuai baharu',
    'Edit custom project role' => 'Edit peranan projek tersuai',
    'Remove a custom role' => 'Alih keluar peranan tersuai',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Adakah anda benar-benar mahu mengalih keluar peranan tersuai ini: "%s"? Semua orang yang diberikan peranan ini akan menjadi ahli projek.',
    'There is no custom role for this project.' => 'Tiada peranan tersuai untuk projek ini.',
    'New project restriction for the role "%s"' => 'Sekatan projek baharu untuk peranan "%s"',
    'Restriction' => 'Sekatan',
    'Remove a project restriction' => 'Alih keluar sekatan projek',
    'Do you really want to remove this project restriction: "%s"?' => 'Adakah anda benar-benar mahu mengalih keluar sekatan projek ini: "%s"?',
    'Duplicate to multiple projects' => 'Gandakan ke pelbagai projek',
    'This field is required' => 'Ruang ini diperlukan',
    'Moving a task is not permitted' => 'Memindahkan tugas tidak dibenarkan',
    'This value must be in the range %d to %d' => 'Nilai ini mestilah dalam julat %d hingga %d',
    'You are not allowed to move this task.' => 'Anda tidak dibenarkan untuk memindahkan tugas ini.',
    'API User Access' => 'Akses Pengguna API',
    'Preview' => 'Pratonton',
    'Write' => 'Tulis',
    'Write your text in Markdown' => 'Tulis teks anda dalam Markdown',
    'No personal API access token registered.' => 'Tiada token akses API peribadi didaftarkan.',
    'Your personal API access token is "%s"' => 'Token akses API peribadi anda ialah "%s"',
    'Remove your token' => 'Alih keluar token anda',
    'Generate a new token' => 'Jana token baharu',
    'Showing %d-%d of %d' => 'Memaparkan %d-%d daripada %d',
    'Outgoing Emails' => 'E-mel Keluar',
    'Add or change currency rate' => 'Tambah atau ubah kadar mata wang',
    'Reference currency: %s' => 'Mata wang rujukan: %s',
    'Add custom filters' => 'Tambah penapis tersuai',
    'Export' => 'Eksport',
    'Add link label' => 'Tambah label pautan',
    'Incompatible Plugins' => 'Pemalam Tidak Serasi',
    'Compatibility' => 'Keserasian',
    'Permissions and ownership' => 'Kebenaran dan pemilikan',
    'Priorities' => 'Keutamaan',
    'Close this window' => 'Tutup tetingkap ini',
    'Unable to upload this file.' => 'Tidak dapat memuat naik fail ini.',
    'Import tasks' => 'Import tugas',
    'Choose a project' => 'Pilih projek',
    'Profile' => 'Profil',
    'Application role' => 'Peranan aplikasi',
    '%d invitations were sent.' => '%d jemputan telah dihantar.',
    '%d invitation was sent.' => '%d jemputan telah dihantar.',
    'Unable to create this user.' => 'Tidak dapat mencipta pengguna ini.',
    'Kanboard Invitation' => 'Jemputan Kanboard',
    'Visible on dashboard' => 'Terlihat pada papan pemuka',
    'Created at:' => 'Dicipta pada:',
    'Updated at:' => 'Dikemas kini pada:',
    'There is no custom filter.' => 'Tiada penapis tersuai.',
    'New User' => 'Pengguna Baharu',
    'Authentication' => 'Pengesahan',
    'If checked, this user will use a third-party system for authentication.' => 'Jika ditandakan, pengguna ini akan menggunakan sistem pihak ketiga untuk pengesahan.',
    'The password is necessary only for local users.' => 'Kata laluan hanya diperlukan untuk pengguna tempatan.',
    'You have been invited to register on Kanboard.' => 'Anda telah dijemput untuk mendaftar di Kanboard.',
    'Click here to join your team' => 'Klik di sini untuk menyertai pasukan anda',
    'Invite people' => 'Jemput orang',
    'Emails' => 'E-mel',
    'Enter one email address by line.' => 'Masukkan satu alamat e-mel setiap baris.',
    'Add these people to this project' => 'Tambah orang-orang ini ke projek ini',
    'Add this person to this project' => 'Tambah orang ini ke projek ini',
    'Sign-up' => 'Daftar',
    'Credentials' => 'Kelayakan',
    'New user' => 'Pengguna baharu',
    'This username is already taken' => 'Nama pengguna ini sudah digunakan',
    'Your profile must have a valid email address.' => 'Profil anda mesti mempunyai alamat e-mel yang sah.',
    'TRL - Turkish Lira' => 'TRL - Lira Turki',
    'The project email is optional and could be used by several plugins.' => 'E-mel projek adalah pilihan dan boleh digunakan oleh beberapa pemalam.',
    'The project email must be unique across all projects' => 'E-mel projek mestilah unik di semua projek',
    'The email configuration has been disabled by the administrator.' => 'Konfigurasi e-mel telah dilumpuhkan oleh pentadbir.',
    'Close this project' => 'Tutup projek ini',
    'Open this project' => 'Buka projek ini',
    'Close a project' => 'Tutup projek',
    'Do you really want to close this project: "%s"?' => 'Adakah anda benar-benar mahu menutup projek ini: "%s"?',
    'Reopen a project' => 'Buka semula projek',
    'Do you really want to reopen this project: "%s"?' => 'Adakah anda benar-benar mahu membuka semula projek ini: "%s"?',
    'This project is open' => 'Projek ini dibuka',
    'This project is closed' => 'Projek ini ditutup',
    'Unable to upload files, check the permissions of your data folder.' => 'Tidak dapat memuat naik fail, periksa kebenaran folder data anda.',
    'Another category with the same name exists in this project' => 'Kategori lain dengan nama yang sama wujud dalam projek ini',
    'Comment sent by email successfully.' => 'Komen berjaya dihantar melalui e-mel.',
    'Sent by email to "%s" (%s)' => 'Dihantar melalui e-mel kepada "%s" (%s)',
    'Unable to read uploaded file.' => 'Tidak dapat membaca fail yang dimuat naik.',
    'Database uploaded successfully.' => 'Pangkalan data berjaya dimuat naik.',
    'Task sent by email successfully.' => 'Tugas berjaya dihantar melalui e-mel.',
    'There is no category in this project.' => 'Tiada kategori dalam projek ini.',
    'Send by email' => 'Hantar melalui e-mel',
    'Create and send a comment by email' => 'Cipta dan hantar komen melalui e-mel',
    'Subject' => 'Subjek',
    'Upload the database' => 'Muat naik pangkalan data',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Anda boleh memuat naik pangkalan data Sqlite yang dimuat turun sebelum ini (format Gzip).',
    'Database file' => 'Fail pangkalan data',
    'Upload' => 'Muat naik',
    'Your project must have at least one active swimlane.' => 'Projek anda mesti mempunyai sekurang-kurangnya satu lajur aktif.',
    'Project: %s' => 'Projek: %s',
    'Automatic action not found: "%s"' => 'Tindakan automatik tidak ditemui: "%s"',
    '%d projects' => '%d projek',
    '%d project' => '%d projek',
    'There is no project.' => 'Tiada projek.',
    'Sort' => 'Isih',
    'Project ID' => 'ID Projek',
    'Project name' => 'Nama projek',
    'Public' => 'Awam',
    'Personal' => 'Peribadi',
    '%d tasks' => '%d tugas',
    '%d task' => '%d tugas',
    'Task ID' => 'ID Tugas',
    'Assign automatically a color when due date is expired' => 'Berikan warna secara automatik apabila tarikh tamat tempoh telah tamat',
    'Total score in this column across all swimlanes' => 'Jumlah markah dalam lajur ini di semua lajur',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Peso Argentina',
    'COP - Colombian Peso' => 'COP - Peso Colombia',
    '%d groups' => '%d kumpulan',
    '%d group' => '%d kumpulan',
    'Group ID' => 'ID Kumpulan',
    'External ID' => 'ID Luaran',
    '%d users' => '%d pengguna',
    '%d user' => '%d pengguna',
    'Hide subtasks' => 'Sembunyikan subtugas',
    'Show subtasks' => 'Tunjukkan subtugas',
    'Authentication Parameters' => 'Parameter Pengesahan',
    'API Access' => 'Akses API',
    'No users found.' => 'Tiada pengguna ditemui.',
    'User ID' => 'ID Pengguna',
    'Notifications are activated' => 'Pemberitahuan diaktifkan',
    'Notifications are disabled' => 'Pemberitahuan dilumpuhkan',
    'User disabled' => 'Pengguna dilumpuhkan',
    '%d notifications' => '%d pemberitahuan',
    '%d notification' => '%d pemberitahuan',
    'There is no external integration installed.' => 'Tiada integrasi luaran dipasang.',
    'You are not allowed to update tasks assigned to someone else.' => 'Anda tidak dibenarkan untuk mengemas kini tugas yang diberikan kepada orang lain.',
    'You are not allowed to change the assignee.' => 'Anda tidak dibenarkan untuk menukar penerima tugas.',
    'Task suppression is not permitted' => 'Penindasan tugas tidak dibenarkan',
    'Changing assignee is not permitted' => 'Menukar penerima tugas tidak dibenarkan',
    'Update only assigned tasks is permitted' => 'Kemas kini hanya tugas yang diberikan dibenarkan',
    'Only for tasks assigned to the current user' => 'Hanya untuk tugas yang diberikan kepada pengguna semasa',
    'My projects' => 'Projek saya',
    'You are not a member of any project.' => 'Anda bukan ahli mana-mana projek.',
    'My subtasks' => 'Subtugas saya',
    '%d subtasks' => '%d subtugas',
    '%d subtask' => '%d subtugas',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Memindahkan tugas antara lajur tersebut hanya dibenarkan untuk tugas yang diberikan kepada pengguna semasa',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Krona Denmark',
    'Remove user from group' => 'Alih keluar pengguna dari kumpulan',
    'Assign the task to its creator' => 'Berikan tugas kepada penciptanya',
    'This task was sent by email to "%s" with subject "%s".' => 'Tugas ini telah dihantar melalui e-mel kepada "%s" dengan subjek "%s".',
    'Predefined Email Subjects' => 'Subjek E-mel Pratakrif',
    'Write one subject by line.' => 'Tulis satu subjek setiap baris.',
    'Create another link' => 'Cipta pautan lain',
    'BRL - Brazilian Real' => 'BRL - Real Brazil',
    'Add a new Kanboard task' => 'Tambah tugas Kanboard baharu',
    'Subtask not started' => 'Subtugas belum dimulakan',
    'Subtask currently in progress' => 'Subtugas sedang dijalankan',
    'Subtask completed' => 'Subtugas selesai',
    'Subtask added successfully.' => 'Subtugas berjaya ditambahkan.',
    '%d subtasks added successfully.' => '%d subtugas berjaya ditambahkan.',
    'Enter one subtask by line.' => 'Masukkan satu subtugas setiap baris.',
    'Predefined Contents' => 'Kandungan Pratakrif',
    'Predefined contents' => 'Kandungan pratakrif',
    'Predefined Task Description' => 'Penerangan Tugas Pratakrif',
    'Do you really want to remove this template? "%s"' => 'Adakah anda benar-benar mahu mengalih keluar templat ini? "%s"',
    'Add predefined task description' => 'Tambah penerangan tugas pratakrif',
    'Predefined Task Descriptions' => 'Penerangan Tugas Pratakrif',
    'Template created successfully.' => 'Templat berjaya dicipta.',
    'Unable to create this template.' => 'Tidak dapat mencipta templat ini.',
    'Template updated successfully.' => 'Templat berjaya dikemas kini.',
    'Unable to update this template.' => 'Tidak dapat mengemas kini templat ini.',
    'Template removed successfully.' => 'Templat berjaya dialih keluar.',
    'Unable to remove this template.' => 'Tidak dapat mengalih keluar templat ini.',
    'Template for the task description' => 'Templat untuk penerangan tugas',
    'The start date is greater than the end date' => 'Tarikh mula lebih besar daripada tarikh tamat',
    'Tags must be separated by a comma' => 'Tag mestilah dipisahkan oleh koma',
    'Only the task title is required' => 'Hanya tajuk tugas diperlukan',
    'Creator Username' => 'Nama Pengguna Pencipta',
    'Color Name' => 'Nama Warna',
    'Column Name' => 'Nama Lajur',
    'Swimlane Name' => 'Nama Lajur',
    'Time Estimated' => 'Anggaran Masa',
    'Time Spent' => 'Masa Dihabiskan',
    'External Link' => 'Pautan Luaran',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Ciri ini membolehkan suapan iCal, suapan RSS dan paparan papan awam.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Hentikan pemasa semua subtugas apabila memindahkan tugas ke lajur lain',
    'Subtask Title' => 'Tajuk Subtugas',
    'Add a subtask and activate the timer when moving a task to another column' => 'Tambah subtugas dan aktifkan pemasa apabila memindahkan tugas ke lajur lain',
    'days' => 'hari',
    'minutes' => 'minit',
    'seconds' => 'saat',
    'Assign automatically a color when preset start date is reached' => 'Berikan warna secara automatik apabila tarikh mula pratetap dicapai',
    'Move the task to another column once a predefined start date is reached' => 'Pindahkan tugas ke lajur lain apabila tarikh mula pratakrif dicapai',
    'This task is now linked to the task %s with the relation "%s"' => 'Tugas ini kini dipautkan ke tugas %s dengan hubungan "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Pautan dengan hubungan "%s" ke tugas %s telah dialih keluar',
    'Custom Filter:' => 'Penapis Tersuai:',
    'Unable to find this group.' => 'Tidak dapat mencari kumpulan ini.',
    '%s moved the task #%d to the column "%s"' => '%s memindahkan tugas #%d ke lajur "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s memindahkan tugas #%d ke kedudukan %d dalam lajur "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s memindahkan tugas #%d ke lajur "%s"',
    '%sh spent' => '%sj dihabiskan',
    '%sh estimated' => '%sj dianggarkan',
    'Select All' => 'Pilih Semua',
    'Unselect All' => 'Nyahpilih Semua',
    'Apply action' => 'Mohon tindakan',
    'Move selected tasks to another column or swimlane' => 'Pindahkan tugas terpilih ke lajur atau lajur lain',
    'Edit tasks in bulk' => 'Edit tugas secara pukal',
    'Choose the properties that you would like to change for the selected tasks.' => 'Pilih sifat yang anda ingin ubah untuk tugas terpilih.',
    'Configure this project' => 'Konfigurasi projek ini',
    'Start now' => 'Mula sekarang',
    '%s removed a file from the task #%d' => '%s mengalih keluar fail dari tugas #%d',
    'Attachment removed from task #%d: %s' => 'Lampiran dialih keluar dari tugas #%d: %s',
    'No color' => 'Tiada warna',
    'Attachment removed "%s"' => 'Lampiran dialih keluar "%s"',
    '%s removed a file from the task %s' => '%s mengalih keluar fail dari tugas %s',
    'Move the task to another swimlane when assigned to a user' => 'Pindahkan tugas ke lajur lain apabila diberikan kepada pengguna',
    'Destination swimlane' => 'Lajur destinasi',
    'Assign a category when the task is moved to a specific swimlane' => 'Berikan kategori apabila tugas dipindahkan ke lajur tertentu',
    'Move the task to another swimlane when the category is changed' => 'Pindahkan tugas ke lajur lain apabila kategori ditukar',
    'Reorder this column by priority (ASC)' => 'Susun semula lajur ini mengikut keutamaan (ASC)',
    'Reorder this column by priority (DESC)' => 'Susun semula lajur ini mengikut keutamaan (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Susun semula lajur ini mengikut penerima dan keutamaan (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Susun semula lajur ini mengikut penerima dan keutamaan (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Susun semula lajur ini mengikut penerima (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Susun semula lajur ini mengikut penerima (Z-A)',
    'Reorder this column by due date (ASC)' => 'Susun semula lajur ini mengikut tarikh tamat tempoh (ASC)',
    'Reorder this column by due date (DESC)' => 'Susun semula lajur ini mengikut tarikh tamat tempoh (DESC)',
    'Reorder this column by id (ASC)' => 'Susun semula lajur ini mengikut id (ASC)',
    'Reorder this column by id (DESC)' => 'Susun semula lajur ini mengikut id (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s memindahkan tugas #%d "%s" ke projek "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Tugas #%d "%s" telah dipindahkan ke projek "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Pindahkan tugas ke lajur lain apabila tarikh tamat tempoh kurang daripada bilangan hari tertentu',
    'Automatically update the start date when the task is moved away from a specific column' => 'Kemas kini tarikh mula secara automatik apabila tugas dialihkan dari lajur tertentu',
    'HTTP Client:' => 'Klien HTTP:',
    'Assigned' => 'Ditugaskan',
    'Task limits apply to each swimlane individually' => 'Had tugas dikenakan kepada setiap lajur secara individu',
    'Column task limits apply to each swimlane individually' => 'Had tugas lajur dikenakan kepada setiap lajur secara individu',
    'Column task limits are applied to each swimlane individually' => 'Had tugas lajur dikenakan kepada setiap lajur secara individu',
    'Column task limits are applied across swimlanes' => 'Had tugas lajur dikenakan di seluruh lajur',
    'Task limit: ' => 'Had tugas: ',
    'Change to global tag' => 'Tukar kepada tag global',
    'Do you really want to make the tag "%s" global?' => 'Adakah anda benar-benar mahu menjadikan tag "%s" global?',
    'Enable global tags for this project' => 'Dayakan tag global untuk projek ini',
    'Group membership(s):' => 'Keahlian kumpulan:',
    '%s is a member of the following group(s): %s' => '%s adalah ahli kumpulan berikut: %s',
    '%d/%d group(s) shown' => '%d/%d kumpulan ditunjukkan',
    'Subtask creation or modification' => 'Penciptaan atau pengubahsuaian subtugas',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Berikan tugas kepada pengguna tertentu apabila tugas dipindahkan ke lajur tertentu',
    'Comment' => 'Komen',
    'Collapse vertically' => 'Runtuhkan secara menegak',
    'Expand vertically' => 'Kembangkan secara menegak',
    'MXN - Mexican Peso' => 'MXN - Peso Meksiko',
    'Estimated vs actual time per column' => 'Anggaran vs masa sebenar setiap lajur',
    'HUF - Hungarian Forint' => 'HUF - Forint Hungary',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Anda mesti memilih fail untuk dimuat naik sebagai avatar anda!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Fail yang anda muat naik bukan imej yang sah! (Hanya *.gif, *.jpg, *.jpeg dan *.png dibenarkan!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Tetapkan tarikh tamat tempoh secara automatik apabila tugas dialihkan dari lajur tertentu',
    'No other projects found.' => 'Tiada projek lain ditemui.',
    'Tasks copied successfully.' => 'Tugas berjaya disalin.',
    'Unable to copy tasks.' => 'Tidak dapat menyalin tugas.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Tema cerah',
    'Dark theme' => 'Tema gelap',
    'Automatic theme - Sync with system' => 'Tema automatik - Segerak dengan sistem',
    'Application managers or more' => 'Pengurus aplikasi atau lebih',
    'Administrators' => 'Pentadbir',
    'Visibility:' => 'Kebolehlihatan:',
    'Standard users' => 'Pengguna standard',
    'Visibility is required' => 'Kebolehlihatan diperlukan',
    'The visibility should be an app role' => 'Kebolehlihatan hendaklah peranan aplikasi',
    'Reply' => 'Balas',
    '%s wrote: ' => '%s menulis: ',
    'Number of visible tasks in this column and swimlane' => 'Bilangan tugas yang kelihatan dalam lajur dan laluan renang ini',
    'Number of tasks in this swimlane' => 'Bilangan tugas dalam laluan renang ini',
    'Unable to find another subtask in progress, you can close this window.' => 'Tidak dapat mencari subtugas lain dalam proses, anda boleh menutup tetingkap ini.',
    'This theme is invalid' => 'Tema ini tidak sah',
    'This role is invalid' => 'Peranan ini tidak sah',
    'This timezone is invalid' => 'Zon waktu ini tidak sah',
    'This language is invalid' => 'Bahasa ini tidak sah',
    'This URL is invalid' => 'URL ini tidak sah',
    'Date format invalid' => 'Format tarikh tidak sah',
    'Time format invalid' => 'Format masa tidak sah',
    'Invalid Mail transport' => 'Pengangkutan Mel tidak sah',
    'Color invalid' => 'Warna tidak sah',
    'This value must be greater or equal to %d' => 'Nilai ini mestilah lebih besar daripada atau sama dengan %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Tambah BOM di permulaan fail (diperlukan untuk Microsoft Excel)',
    'Just add these tag(s)' => 'Hanya tambah tag ini',
    'Remove internal link(s)' => 'Buang pautan dalaman',
    'Import tasks from another project' => 'Import tugas dari projek lain',
    'Select the project to copy tasks from' => 'Pilih projek untuk menyalin tugas dari',
    'The total maximum allowed attachments size is %sB.' => 'Jumlah saiz lampiran maksimum yang dibenarkan ialah %sB.',
    'Add attachments' => 'Tambah lampiran',
    'Task #%d "%s" is overdue' => 'Tugas #%d « %s » telah tamat tempoh',
    'Enable notifications by default for all new users' => 'Dayakan pemberitahuan secara lalai untuk semua pengguna baharu',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Tetapkan tugasan kepada penciptanya untuk lajur tertentu jika tiada penerima tugasan ditetapkan secara manual',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Tetapkan tugasan kepada pengguna yang log masuk apabila lajur berubah ke lajur yang ditetapkan jika tiada pengguna ditetapkan',
];
